@@ -38,7 +38,7 @@ def transform_date(types, date_format, datetime_format, values):
             except:
                 print(f"Date format provided does not match incoming value and is not able to be converted to %Y-%m-%d")
                 pass
-        if types[i] == "DATETIME" or types[i] == "TIMESTAMP" and value:
+        if (types[i] == "DATETIME" or types[i] == "TIMESTAMP") and value:
             try:
                 if datetime_format:
                     dt = datetime.strptime(value, datetime_format)
@@ -121,7 +121,7 @@ def is_schema_valid(types, modes, names, values):
             except ValueError:
                 logging.info(f"Column {names[i]} is defined as DATE but incoming value is not DATE")
                 return False
-        if types[i] == "DATETIME" or types[i] == "TIMESTAMP" and value:
+        if (types[i] == "DATETIME" or types[i] == "TIMESTAMP") and value:
             try:
                 value = value.strip()
                 if len(value) > 23:
